<?php        
namespace Concrete\Package\Achillea;
use Package;
use BlockType;
use BlockTypeSet;
use PageTheme;
use PageTemplate;
use Concrete\Core\Attribute\Type as AttributeType;
use CollectionAttributeKey;
use Concrete\Core\Attribute\Key\Category as AttributeKeyCategory;
use Concrete\Core\Attribute\Set as AttributeSet;

class Controller extends Package {

	protected $pkgHandle = 'achillea';
	protected $appVersionRequired = '5.7.5.6';
	protected $pkgVersion = '0.9.8';
	protected $pkgAllowsFullContentSwap = true;
		
	public function getPackageDescription()
	{
		return t("Achillea is an elegant and creative Bootstrap theme, with beautiful typography, useful custom blocks and templates.");
	}

	public function getPackageName()
	{
		return t("Achillea");
	}
	
	public function install()
	{
     $pkg = parent::install();
	BlockTypeSet::add("achillea","Achillea", $pkg);
    $bt = BlockType::getByHandle('achillea_accordion');
if (!is_object($bt)) {
    $bt = BlockType::installBlockType('achillea_accordion', $pkg);
    }  
    $bt = BlockType::getByHandle('achillea_bootstrap_thumbnail');
if (!is_object($bt)) {
    $bt = BlockType::installBlockType('achillea_bootstrap_thumbnail', $pkg);
    }  
    $bt = BlockType::getByHandle('achillea_button');
if (!is_object($bt)) {
    $bt = BlockType::installBlockType('achillea_button', $pkg);
    }  
       $bt = BlockType::getByHandle('achillea_highlight_box');
if (!is_object($bt)) {
    $bt = BlockType::installBlockType('achillea_highlight_box', $pkg);
    }
       $bt = BlockType::getByHandle('achillea_image_feature');
if (!is_object($bt)) {
    $bt = BlockType::installBlockType('achillea_image_feature', $pkg);
    }  
       $bt = BlockType::getByHandle('achillea_team_member');
if (!is_object($bt)) {
    $bt = BlockType::installBlockType('achillea_team_member', $pkg);
    }  
        $this->pageTemplates($pkg);
		$this->installPageAttributes($pkg);
		PageTheme::add('achillea', $pkg);			

  	}
	
	private function pageTemplates($pkg) {
		
		if (!PageTemplate::getByHandle('blog_entry')) {
            PageTemplate::add('blog_entry', t('Blog Entry'), 'right_sidebar.png', $pkg);
        }
		
        if (!PageTemplate::getByHandle('full')) {
            PageTemplate::add('full', t('Full'), 'full.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('home')) {
            PageTemplate::add('home', t('Home'), 'full.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('home_v2')) {
            PageTemplate::add('home_v2', t('Home V2'), 'full.png', $pkg);
        }
	
		if (!PageTemplate::getByHandle('left_sidebar')) {
            PageTemplate::add('left_sidebar', t('Left Sidebar'), 'left_sidebar.png', $pkg);
        }
		
        if (!PageTemplate::getByHandle('portfolio_item')) {
            PageTemplate::add('portfolio_item', t('Portfolio Item'), 'right_sidebar.png', $pkg);
        }
		
        if (!PageTemplate::getByHandle('right_sidebar')) {
            PageTemplate::add('right_sidebar', t('Right Sidebar'), 'right_sidebar.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('three_columns')) {
            PageTemplate::add('three_columns', t('Three Columns'), 'three_column.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('three_over_two')) {
            PageTemplate::add('three_over_two', t('Three Over Two'), 'three_column.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('two_columns')) {
            PageTemplate::add('two_columns', t('Two Columns'), 'two_column.png', $pkg);
        }
		
    }

  private function installPageAttributes(&$pkg) {
    $akCatSet = AttributeSet::getByHandle('achillea_set');
    if(!is_object($akCatSet)){
      $akCat = AttributeKeyCategory::getByHandle('collection');
      $akCat->setAllowAttributeSets(AttributeKeyCategory::ASET_ALLOW_SINGLE);
      $akCatSet = $akCat->addSet('achillea_set', t('Achillea Set'),$pkg);
    }
	
	$imgAttr = AttributeType::getByHandle('image_file'); 
  	$achilleaBannerImage = CollectionAttributeKey::getByHandle('achillea_banner_image'); 
	 if( !is_object($achilleaBannerImage) ) {
     CollectionAttributeKey::add($imgAttr, 
        	array('akHandle' => 'achillea_banner_image', 
          'akName' => t('Achillea Masthead Image'), 
        ),$pkg)->setAttributeSet($akCatSet); 
		
	 }
	$imgAttr = AttributeType::getByHandle('image_file'); 
  	$achilleaHomeFw1 = CollectionAttributeKey::getByHandle('achillea_home_fw1'); 
	 if( !is_object($achilleaHomeFw1) ) {
     CollectionAttributeKey::add($imgAttr, 
        	array('akHandle' => 'achillea_home_fw1', 
          'akName' => t('Achillea Home Full Width 1'), 
        ),$pkg)->setAttributeSet($akCatSet); 
		
	 }	 
	$imgAttr = AttributeType::getByHandle('image_file'); 
  	$achilleaHomeFw1 = CollectionAttributeKey::getByHandle('achillea_home_fw2'); 
	 if( !is_object($achilleaHomeFw2) ) {
     CollectionAttributeKey::add($imgAttr, 
        	array('akHandle' => 'achillea_home_fw2', 
          'akName' => t('Achillea Home Full Width 2'), 
        ),$pkg)->setAttributeSet($akCatSet); 
		
	 }	 
	$imgAttr = AttributeType::getByHandle('image_file'); 
  	$achilleaThumb = CollectionAttributeKey::getByHandle('achillea_thumbnail'); 
	 if( !is_object($achilleaThumb) ) {
     CollectionAttributeKey::add($imgAttr, 
        	array('akHandle' => 'achillea_thumbnail', 
          'akName' => t('Achillea Thumbnail'), 
        ),$pkg)->setAttributeSet($akCatSet); 
 	
	  }
  	$imgAttr = AttributeType::getByHandle('image_file'); 
	$achilleaPortfolioImage = CollectionAttributeKey::getByHandle('achillea_portfolio_image'); 
	 if( !is_object($achilleaPortfolioImage) ) {
     CollectionAttributeKey::add($imgAttr, 
        	array('akHandle' => 'achillea_portfolio_image', 
          'akName' => t('Achillea Portfolio Item Image'), 
        ),$pkg)->setAttributeSet($akCatSet); 
	}
  }
}